@@ -1,10 +1,10 @@
 imageINFLUENCE<-function(B, sta, proj)
   {
     NEX = 50
-    col=tomo.colors(50)
+    col=RSEIS::tomo.colors(50)
      Mz = match(B$names, sta$name)
      
-     gxy = GLOB.XY(  sta$lat[Mz]   ,sta$lon[Mz] , proj)
+     gxy = GEOmap::GLOB.XY(  sta$lat[Mz]   ,sta$lon[Mz] , proj)
      
      ex = seq(from=min(gxy$x), to=max(gxy$x), length=NEX)
     why = seq(from=min(gxy$y), to=max(gxy$y), length=NEX)
@@ -12,7 +12,7 @@ imageINFLUENCE<-function(B, sta, proj)
      mval = as.vector(B$stats[3, ])
 
     DF = cbind(x=gxy$x , y=gxy$y ,  z=mval)
- zed  = mba.surf(DF, NEX, NEX, n = 8, m = 8, h = 8, extend=TRUE)$xyz.est
+ zed  = MBA::mba.surf(DF, NEX, NEX, n = 8, m = 8, h = 8, extend=TRUE)$xyz.est
      ex = zed[[1]]
     why = zed[[2]]
 
